package sun.management.snmp.jvminstr;

import sun.management.snmp.util.JvmContextFactory;
import com.sun.jmx.snmp.SnmpStatusException;
import com.sun.jmx.mbeanserver.Util;
import java.util.Map;
import java.io.File;
import java.lang.management.ManagementFactory;
import java.lang.management.RuntimeMXBean;
import javax.management.MBeanServer;
import com.sun.jmx.snmp.agent.SnmpMib;
import sun.management.snmp.jvmmib.EnumJvmRTBootClassPathSupport;
import sun.management.snmp.jvmmib.JvmRuntimeMBean;

public class JvmRuntimeImpl implements JvmRuntimeMBean
{
    static final EnumJvmRTBootClassPathSupport JvmRTBootClassPathSupportSupported;
    static final EnumJvmRTBootClassPathSupport JvmRTBootClassPathSupportUnSupported;
    
    public JvmRuntimeImpl(SnmpMib snmpMib) {
    }
    
    public JvmRuntimeImpl(SnmpMib snmpMib, MBeanServer mBeanServer) {
    }
    
    static RuntimeMXBean getRuntimeMXBean() {
        return ManagementFactory.getRuntimeMXBean();
    }
    
    private static String validDisplayStringTC(String s) {
        return JVM_MANAGEMENT_MIB_IMPL.validDisplayStringTC(s);
    }
    
    private static String validPathElementTC(String s) {
        return JVM_MANAGEMENT_MIB_IMPL.validPathElementTC(s);
    }
    
    private static String validJavaObjectNameTC(String s) {
        return JVM_MANAGEMENT_MIB_IMPL.validJavaObjectNameTC(s);
    }
    
    static String[] splitPath(String s) {
        return s.split(File.pathSeparator);
    }
    
    static String[] getClassPath(Object o) {
        Map<String, String> map = (Map)Util.cast((o instanceof Map) ? o : null);
        if (map != null) {
            String[] array = (String[])(String[])map.get("JvmRuntime.getClassPath");
            if (array != null) {
                return array;
            }
        }
        String[] splitPath = splitPath(getRuntimeMXBean().getClassPath());
        if (map != null) {
            map.put("JvmRuntime.getClassPath", splitPath);
            return splitPath;
        }
        return splitPath;
    }
    
    static String[] getBootClassPath(Object o) {
        if (!getRuntimeMXBean().isBootClassPathSupported()) {
            return new String[0];
        }
        Map<String, String> map = (Map)Util.cast((o instanceof Map) ? o : null);
        if (map != null) {
            String[] array = (String[])(String[])map.get("JvmRuntime.getBootClassPath");
            if (array != null) {
                return array;
            }
        }
        String[] splitPath = splitPath(getRuntimeMXBean().getBootClassPath());
        if (map != null) {
            map.put("JvmRuntime.getBootClassPath", splitPath);
            return splitPath;
        }
        return splitPath;
    }
    
    static String[] getLibraryPath(Object o) {
        Map<String, String> map = (Map)Util.cast((o instanceof Map) ? o : null);
        if (map != null) {
            String[] array = (String[])(String[])map.get("JvmRuntime.getLibraryPath");
            if (array != null) {
                return array;
            }
        }
        String[] splitPath = splitPath(getRuntimeMXBean().getLibraryPath());
        if (map != null) {
            map.put("JvmRuntime.getLibraryPath", splitPath);
            return splitPath;
        }
        return splitPath;
    }
    
    static String[] getInputArguments(Object o) {
        Map<String, String> map = (Map)Util.cast((o instanceof Map) ? o : null);
        if (map != null) {
            String[] array = (String[])(String[])map.get("JvmRuntime.getInputArguments");
            if (array != null) {
                return array;
            }
        }
        String[] array2 = (String[])getRuntimeMXBean().getInputArguments().toArray(new String[0]);
        if (map != null) {
            map.put("JvmRuntime.getInputArguments", array2);
            return array2;
        }
        return array2;
    }
    
    public String getJvmRTSpecVendor() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getSpecVendor());
    }
    
    public String getJvmRTSpecName() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getSpecName());
    }
    
    public String getJvmRTVMVersion() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getVmVersion());
    }
    
    public String getJvmRTVMVendor() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getVmVendor());
    }
    
    public String getJvmRTManagementSpecVersion() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getManagementSpecVersion());
    }
    
    public String getJvmRTVMName() throws SnmpStatusException {
        return validJavaObjectNameTC(getRuntimeMXBean().getVmName());
    }
    
    public Integer getJvmRTInputArgsCount() throws SnmpStatusException {
        return new Integer(getInputArguments(JvmContextFactory.getUserData()).length);
    }
    
    public EnumJvmRTBootClassPathSupport getJvmRTBootClassPathSupport() throws SnmpStatusException {
        if (getRuntimeMXBean().isBootClassPathSupported()) {
            return JvmRuntimeImpl.JvmRTBootClassPathSupportSupported;
        }
        return JvmRuntimeImpl.JvmRTBootClassPathSupportUnSupported;
    }
    
    public Long getJvmRTUptimeMs() throws SnmpStatusException {
        return new Long(getRuntimeMXBean().getUptime());
    }
    
    public Long getJvmRTStartTimeMs() throws SnmpStatusException {
        return new Long(getRuntimeMXBean().getStartTime());
    }
    
    public String getJvmRTSpecVersion() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getSpecVersion());
    }
    
    public String getJvmRTName() throws SnmpStatusException {
        return validDisplayStringTC(getRuntimeMXBean().getName());
    }
    
    static {
        JvmRTBootClassPathSupportSupported = new EnumJvmRTBootClassPathSupport("supported");
        JvmRTBootClassPathSupportUnSupported = new EnumJvmRTBootClassPathSupport("unsupported");
    }
}
